Miscellaneous routines
**********************

.. toctree::

.. currentmodule:: numpy

Performance tuning
------------------
.. autosummary::
   :toctree: generated/

   setbufsize
   getbufsize

Memory ranges
-------------

.. autosummary::
   :toctree: generated/

   shares_memory
   may_share_memory
   byte_bounds

Array mixins
------------
.. autosummary::
   :toctree: generated/

   lib.mixins.NDArrayOperatorsMixin

NumPy version comparison
------------------------
.. autosummary::
   :toctree: generated/

   lib.NumpyVersion

Utility
-------

.. autosummary::
   :toctree: generated/

   get_include
   show_config
   deprecate
   deprecate_with_doc
   broadcast_shapes

Matlab-like Functions
---------------------
.. autosummary::
   :toctree: generated/

   who
   disp

Exceptions
----------
.. autosummary::
   :toctree: generated/

   AxisError
